Description Usage Arguments Examples
View source: R/collinearityR.R
Returns a DataFrame containing Pearson's coefficient, VIF with explanatory variables suggested for elimination. An empty dataframe means no multicollinearity detected.
1 | col_identify(df, X, y, corr_min = -0.8, corr_max = 0.8, vif_limit = 4)
|
df |
An input dataframe |
X |
Explanatory variables (vector of characters) |
y |
Response variable (single vector) |
corr_min |
(optional) A decimal number that serves as a threshold for selecting a pair. This is a Pearson coefficient value. Default set at -0.8. |
corr_max |
(optional) A decimal number that serves as a threshold for selecting a pair. This is a Pearson coefficient value. Default set at 0.8. |
vif_limit |
(optional) A decimal number that serves as a threshold for selecting a pair. This is a VIF value. Default set at 4. |
1 2 | col_identify(iris, c("Sepal.Width", "Petal.Length"),
"Petal.Width", vif_limit = 0, corr_max = 0.3, corr_min = -0.3)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.