corr_heatmap: Plots the dataframe as a color-encoded Pearson correlation...

Description Usage Arguments Details Value Examples

View source: R/collinearityR.R

Description

The rows and the columns contain variable names, while the heatmap tiles contain Pearson correlation coefficient and corresponding colours.

Usage

1
corr_heatmap(df, color_neg, color_pos)

Arguments

df

dataframe. 2-D dataframe.

color_neg

string. The color for the negative correlation.

color_pos

string. The color for the positive correlation.

Details

The inputs must be a 2-D data frame

Value

The heatmap.

Examples

1
corr_heatmap(mtcars[, c(1,3,4,5,6,7)])

UBC-MDS/collinearityR_tool documentation built on Feb. 6, 2022, 9:41 p.m.