vif_bar_plot: Returns a list containing a tibble that includes Variance...

Description Usage Arguments Value Examples

View source: R/collinearityR.R

Description

Returns a list containing a tibble that includes Variance Inflation Factor (VIF) score and a bar chart for the VIF scores alongside the specified threshold for each explanatory variable in a linear regression model.

Usage

1
vif_bar_plot(x, y, df, thresh)

Arguments

x

A vector of the names of the explanatory variables.

y

A string specifying the response variable.

df

A tibble containing the data.

thresh

An integer specifying the threshold.

Value

A list containing a tibble for VIFs and a bar chart of the VIFs for each explanatory variable alongside the threshold.

Examples

1
vif_bar_plot(c("Sepal.Width", "Sepal.Length"), "Petal.Width", iris, 5)

UBC-MDS/collinearityR_tool documentation built on Feb. 6, 2022, 9:41 p.m.