Description Usage Arguments Details Value Examples
View source: R/collinearityR.R
The rows and the columns contain variable names, while the heatmap tiles contain Pearson correlation coefficient and corresponding colours.
1 | corr_heatmap(df, color_neg, color_pos)
|
df |
dataframe. 2-D dataframe. |
color_neg |
string. The color for the negative correlation. |
color_pos |
string. The color for the positive correlation. |
The inputs must be a 2-D data frame
The heatmap.
1 | corr_heatmap(mtcars[, c(1,3,4,5,6,7)])
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.