Description Usage Arguments Value Examples
View source: R/collinearityR.R
Calculates Pearson correlation coefficients for all numeric variables. Rounds the outcome to desired decimals. Outputs a matrix or a dataframe (longer matrix)
1 | corr_matrix(df, decimals = 2)
|
df |
tibble, the input dataframe |
decimals |
int, the number of decimals |
a generic correlation matrix and its longer form that can be passed to other functions in this package.
1 | corr_matrix(tibble::tibble(x = 1:5, y = 2:6))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.