Description Usage Arguments Value Examples
View source: R/collinearityR.R
Returns a list containing a tibble that includes Variance Inflation Factor (VIF) score and a bar chart for the VIF scores alongside the specified threshold for each explanatory variable in a linear regression model.
1 | vif_bar_plot(x, y, df, thresh)
|
x |
A vector of the names of the explanatory variables. |
y |
A string specifying the response variable. |
df |
A tibble containing the data. |
thresh |
An integer specifying the threshold. |
A list containing a tibble for VIFs and a bar chart of the VIFs for each explanatory variable alongside the threshold.
1 | vif_bar_plot(c("Sepal.Width", "Sepal.Length"), "Petal.Width", iris, 5)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.